title:::

- started with: 100 VAC, 1.59 kΩ ~= 6.3 w - heat was not noticeable.
- 2025-11-07: 200 VAC, 1.59 kΩ ~= 25.2 w - heat is noticeable. ✅

- [AI convo](https://chatgpt.com/c/68df585e-9a68-832f-b22e-481af04c377e)

items:::

## parts

continues [v1](./parts-v1.md).

parts_images:::

parts_list:::